#!/usr/bin/python3
from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *
import sys

from qt_material import apply_stylesheet

import TinyMCE_on_Pyqt as editor

class my_TinyMCE(editor.TinyMCE_on_PyQt_window):
    def __init__(self):
        super(my_TinyMCE, self).__init__()
        # 添加保存按钮
        self.save_button = QPushButton("保存文件",self)
        self.save_button.clicked.connect(self.choose_file)
        self.open_button = QPushButton("打开文件",self)
        self.open_button.clicked.connect(self.open_file)
        self.layout.addWidget(self.save_button)
        self.layout.addWidget(self.open_button)

    # 监听键盘
    def keyPressEvent(self, event):
        if QApplication.keyboardModifiers() == Qt.ControlModifier and event.key() == Qt.Key_S: #检测CtrlS保存按键
            self.choose_file()

    def choose_file(self):
        file_url = QFileDialog.getSaveFileName(self, 
              "设置保存位置","./",
              "All Files (*);;Text Files (*.html)")[0]
        self.save_file(file_url)

    def open_file(self):
        file_url = QFileDialog.getOpenFileName(self, 
              "选择打开位置","./",
              "All Files (*);;Text Files (*.html)")[0]
        print(file_url)
        with open(file_url, mode='r', encoding='utf-8') as file_obj:
            self.set_html(file_obj.read())



app=QApplication(sys.argv)
apply_stylesheet(app, theme='dark_teal.xml')
win=my_TinyMCE()
win.init()
win.show()
app.exit(app.exec())


#!/usr/bin/python3
import sys,os
from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *
from PySide6.QtWebEngineWidgets import *
from PySide6.QtWebChannel import *
import logging

import json
import threading

logging.basicConfig(level=logging.DEBUG) #设置日志等级

DIR = os.path.dirname(__file__)

class TinyMCE_on_PyQt_window(QWidget):
    def __init__(self):
        super(TinyMCE_on_PyQt_window, self).__init__()

        self.url = QFileInfo(DIR + "/main.html").absoluteFilePath()
        self.layout = QVBoxLayout() 
        self.TinyMCE_config=json.dumps({ #转为json方便与JS交互
            'selector': '#TinyMCE',
            'language': 'zh_CN',
            'height': 'calc(100vh)',
            'plugins':'code,table,autosave,lists,advlist,anchor,autolink,charmap,emoticons,insertdatetime,media,preview,quickbars,searchreplace,template,wordcount',
            'toolbar': ['aligncenter | alignjustify | alignleft | alignnone | alignright | blockquote | backcolor | blocks | bold | copy | cut | fontfamily | fontsize | forecolor | h1 | h2 | h3 | h4 | h5 | h6 | newdocument | outdent | paste | pastetext | print | redo | remove | removeformat | selectall | strikethrough | styles | subscript | superscript | underline | undo | visualaid | code | restoredraft | bullist | anchor | link | charmap | emoticons | insertdatetime | media | preview | searchreplace | table tabledelete | tableprops tablerowprops tablecellprops | tableinsertrowbefore tableinsertrowafter tabledeleterow | tableinsertcolbefore tableinsertcolafter tabledeletecol | template | wordcount']
        })

        self.refresh_state=True #TinyMCE文本刷新状态，True代表刷新完成内容可用，False代表正在等待JS回调

    def init(self):
        # 创建浏览器控件
        self.browser = QWebEngineView()
        self.browser.load(QUrl("file://"+self.url))

        # 新建QWebChannel
        self.channel = QWebChannel()
        self.browser.page().setWebChannel(self.channel)

        self.browser.page().loadFinished.connect(self.init_TinyMCE)
        
        # 设置QWidget的layout
        self.layout.addWidget(self.browser)
        self.setLayout(self.layout)

    def init_TinyMCE(self):
        #初始化TinyMCE(调用JS)
        self.browser.page().runJavaScript("init_editor('%s');" % self.TinyMCE_config)

    # 刷新TinyMCE编辑器的内容
    def __call_back(self,result):
        logging.info("已收到call back")
        self.content=result
        self.refresh_state=True #回调完成，self.content内容已刷新，内容 可用(最新)
    def refresh_content(self):
        logging.info("开始刷新TinyMCE内容")
        self.refresh_state=False #开始等待回调，内容 不可用(不一定最新)
        self.browser.page().runJavaScript("tinymce.activeEditor.getContent();",0,self.__call_back)
    
    # 当newest为True时，进程将堵塞等待刷新完成
    def get_file(self):
        self.refresh_content() #开始刷新内容
        logging.info("开始堵塞，等待刷新完成")
        while not self.refresh_state: # 当内容没有刷新完成时进行堵塞
            QApplication.processEvents()
            pass
        return self.content

    def save_file(self,url,refresh=True):
        with open(url, mode='w', encoding='utf-8') as file_obj:
            if refresh:
                file_obj.write(self.get_file())
            else:
                file_obj.write(self.content)

    def set_html(self,html_code):
        self.browser.page().runJavaScript("tinymce.activeEditor.setContent('%s');" % html_code)



#!/usr/bin/python3
import setuptools

with open("../README.md", "r") as fh:
    long_description = fh.read()

# print(setuptools.find_packages())


setuptools.setup(
    name="TinyMCE-on-pyqt",
    version="0.1.9",
    author="TimTu",
    author_email="ovo-tim@qq.com",
    description="在pyqt中方便的使用TinyMCE",
    include_package_data=True,
    long_description=long_description,
    license='GPL License',
    long_description_content_type="text/markdown",
    url="https://github.com/ovo-Tim/TinyMCE-on-pyqt",
    packages=["TinyMCE_on_Pyqt"],
    install_requires=['PySide6'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
